Learn R Programming

rollply (version 0.5.0)

build_grid_identical: Build a regular grid

Description

Create a regular grid with the same number of points on each dimension.

Usage

build_grid_identical(coords, npts, pad = 0, ...)

Arguments

coords
A matrix or data frame of coordinates as columns
npts
The approximate total number of points of the output grid
pad
Padding on each dimension (a positive number makes a grid that is larger than the ranges of the coordinates).
...
other arguments are silently ignored

Value

The coordinates of a grid of points as a data frame with approximately npts rows and ncol(coords) columns. Names are transfered from the coords data frame.

Details

This function creates a grid that covers a set of points. The number of points of the output grid is the same on all dimensions. This is probably the only useful option for 1D moving-window computations.

See Also

Other grid.building.functions: build_grid_ahull_crop, build_grid_ahull_fill, build_grid_squaretile