Learn R Programming

rollply (version 0.4.2)

build_grid_squaretile: Create a grid with square tiles

Description

Create a rectangular grid of regularly-spaced points (square tiles).

Usage

build_grid_squaretile(coords, npts, pad = 0, ...)

Arguments

coords
A matrix or data.frame of coordinates with two columns
npts
The approximate total number of points of the output grid
pad
Padding on each dimension (a positive number makes a grid that is larger than the ranges of the coordinates).
...
other arguments are silently ignored

Value

  • The coordinates of a grid of points as a data.frame with approximately npts rows and ncol(coords) columns. Names are transfered from the coords data frame.

Details

This function creates a grid that covers a set of points. The distance between points is the same on all dimensions (tiles are squared. It is only implemented for 2D grid so coords must have at most two columns.

See Also

Other grid.building.functions: build_grid_ahull_crop; build_grid_ahull_fill; build_grid_identical