Learn R Programming

rollply (version 0.5.0)

meadow: Partial Data from a vegetation survey in a Californian subalpine meadow.

Description

Part of the results of a vegetation survey carried out in Yosemite, CA.

Usage

meadow

Arguments

Format

A data frame with 217 rows and 4 variables:
lon
approximate longitude of the plot
lat
approximate latitude of the plot
meanvwc
the mean volumetric water content of the superficial soil
tcover
the total cover of vegetation in the plot

References

A Multi-scale Approach to Searching for Disturbance Effects: Pack Stock and Sierra Nevada Meadows. Steven R. Lee, Eric L. Berlow, Steven M. Ostoja, John R. Matchett, Alexandre Genin, Stephen C. Hart, Matthew L. Brooks (in prep)