build_grid_ahull_crop(coords, npts, pad = NULL, grid_opts = list(alpha = 0.3, scale_alpha = TRUE))alpha that controls the shape
of the alpha hull (see details).data.frame with
ncol(coords) columns. Names are transfered from the
coords data frame.
This function computes the alpha hull of a set of points which is
an estimate of its overall outline. The intricateness of this outline
is determined by the alpha parameter: a value close to zero will
produce a very intricate outline and a high value will produce a coarse
outline (similar to the convex hull). It is highly recommended to try
different values of alpha to see what is most appropriate for one's
datasets.
ahullOther grid.building.functions: build_grid_ahull_fill,
build_grid_identical,
build_grid_squaretile