Learn R Programming

rollply (version 0.4.2)

build_grid_ahull_crop: Regular grid in alpha-hull

Description

Create a grid within the alpha hull of a set of points.

Usage

build_grid_ahull_crop(coords, npts, pad = NULL, grid_opts = list(alpha =
  0.3))

Arguments

coords
A matrix or data.frame of coordinates with two columns
npts
The number of points before cropping to the alpha hull shape
pad
Ignored
grid_opts
A list with component alpha that controls the shape of the alpha hull
...
other arguments are silently ignored

Value

  • The coordinates of a grid of points as a data.frame with ncol(coords) columns. Names are transfered from the coords data frame.

Details

This function creates a rectangular grid, then computes the alpha hull of a set of points, and discards all the points of this grid that fall outside of the hull.

See Also

Other grid.building.functions: build_grid_ahull_fill; build_grid_identical; build_grid_squaretile