Learn R Programming

rollply (version 0.4.2)

build_grid_ahull_fill: Regular grid in alpha-hull

Description

Create a grid within the alpha hull of a set of points.

Usage

build_grid_ahull_fill(coords, npts, pad = NULL, grid_opts = list(alpha =
  0.3, error_tol = 0.05, run_max = 20, verbose = FALSE))

Arguments

coords
A matrix or data.frame of coordinates with two columns
npts
The approximate number of points of the requested grid
pad
ignored.
grid_opts
A list with component alpha that controls the shape of the alpha hull, error_tol the error tolerance as a fraction of the number of points, run_max the maxi

Value

  • The coordinates of a grid of points as a data.frame with approximately npts rows and ncol(coords) columns. Names are transfered from the coords data frame.

Details

This function computes the alpha hull of a set of points, then iteratively finds the best grid of npts points fitting in the hull.

See Also

Other grid.building.functions: build_grid_ahull_crop; build_grid_identical; build_grid_squaretile